<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

use Hekmatinasser\Notowo\Notowo;
use Hekmatinasser\Verta\Verta;

class WIP_Helper {

    public static function get_editable_roles() {
        global $wp_roles;

        $all_roles = $wp_roles->roles;
        $editable_roles = apply_filters('editable_roles', $all_roles);

        return $editable_roles;
    }

    public static function date_format($ts) {
        $options = new WIP_Options_Manager();
        $format = $options->get_option('date-format');
        $format = $format ? $format : 'Y-m-d H:i';
        $repair = $options->get_option('repair-date');

        if ($repair) {
            $timezone = get_option('timezone_string');
            date_default_timezone_set($timezone);
            Verta::setStringformat($format);

            return verta($ts);
        }

        return date_i18n($format, $ts);
    }

    public static function to_word($number) {
        $language = get_bloginfo("language");
        $lang = $language == 'fa-IR' ? 'fa' : 'en';

        return Notowo::parse($number, $lang);
    }

    public static function hex2rgba($color, $opacity = false) {
        $default = 'rgb(0,0,0)';

        if (empty($color)) {
            return $default;
        }

        if ($color[0] == '#') {
            $color = substr($color, 1);
        }

        if (strlen($color) == 6) {
            $hex = array($color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5]);
        } elseif (strlen($color) == 3) {
            $hex = array($color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2]);
        } else {
            return $default;
        }

        $rgb = array_map('hexdec', $hex);

        if ($opacity) {
            if (abs($opacity) > 1) {
                $opacity = 1.0;
            }

            $output = 'rgba(' . implode(",", $rgb) . ',' . $opacity . ')';
        } else {
            $output = 'rgb(' . implode(",", $rgb) . ')';
        }

        return $output;
    }

    public static function is_dokan_dashboard() {
        if (!function_exists('dokan')) {
            return false;
        }

        $dokan_pages = get_option('dokan_pages');
        if (is_array($dokan_pages)) {
            $dashboard = $dokan_pages['dashboard'] ?? null;
            if ($dashboard == get_the_ID()) {
                return true;
            }
        }

        return false;
    }

    public static function get_states($country) {
        $countries = new WC_Countries();
        $states = $countries->get_states();

        return $states[$country] ?? [];
    }

    public static function get_state($country, $state) {
        $states = self::get_states($country);

        return $states[$state] ?? null;
    }

    public static function get_country($country) {
        return WC()->countries->countries[$country];
    }

    public static function customer_orders($user_id) {
        if (!intval($user_id)) {
            return [];
        }

        return get_posts(array(
            'posts_per_page' => -1,
            'meta_key' => '_customer_user',
            'meta_value' => $user_id,
            'post_type' => 'shop_order',
            'post_status' => array_keys(wc_get_order_statuses()),
            'orderby' => 'date',
            'order' => 'ASC',
        ));
    }

    public static function generate_order_id($order_id, $type) {
        $options = new WIP_Options_Manager();
        $count = $options->get_option('print-count-' . $type);
        $count = $count ?? 1;
        $id = '';
        for ($i = 0; $i < $count; $i++) {
            $id .= $order_id;
            if (($i + 1) != $count) {
                $id .= ',';
            }
        }

        return $id;
    }

    public static function check_receiving($order_id) {
        $options = new WIP_Options_Manager();
        if (!$options->get_option('receiving-invoice-selection')) {
            return true;
        }

        global $wpdb;

        $receiving = $wpdb->get_row($wpdb->prepare("SELECT meta_value FROM {$wpdb->postmeta} WHERE post_id = %d AND meta_key = '_billing_receiving_invoice'", $order_id));

        return $receiving == null ? true : is_object($receiving) && $receiving->meta_value;
    }

    public static function get_delivery_meta_item($order_id) {
        global $wpdb, $table_prefix;
        $table = $table_prefix . 'woocommerce_delivery_time';
        $delivery_info = $wpdb->get_results("SELECT * FROM {$table} WHERE `delivery_orders` LIKE '%{$order_id}%' ", 'ARRAY_A');
        if (isset($delivery_info) && !empty($delivery_info)) {
            $delivery_date = $delivery_info[0]['delivery_date'];
            $delivery_hour = $delivery_info[0]['delivery_time'];
            return date_i18n('Y/m/d', strtotime(get_date_from_gmt(date('Y/m/d H:i:s', $delivery_date), 'Y/m/d'))) . ' ' . $delivery_hour;
        }

        return null;
    }
}