<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Notifications {

    private $options;

    public function __construct() {
        $this->options = new WIP_Options_Manager();

        if ($this->options->get_option('send-order-completed')) {
            add_action('woocommerce_order_status_completed', [$this, 'send_email']);
        }
        if ($this->options->get_option('send-order-completed-sms')) {
            add_action('woocommerce_order_status_completed', [$this, 'send_sms']);
        }
        if ($this->options->get_option('send-payment-completed')) {
            add_action('woocommerce_thankyou', [$this, 'send_email']);
        }
        if ($this->options->get_option('send-payment-completed-sms')) {
            add_action('woocommerce_thankyou', [$this, 'send_sms']);
        }
    }

    private function receiving_invoice($order_id) {
        if ($this->options->get_option('receiving-invoice-selection')) {
            return get_post_meta($order_id, '_billing_receiving_invoice', true);
        }

        return true;
    }

    public function send_email($order_id) {
        if (!$this->receiving_invoice($order_id)) {
            return null;
        }

        $order = wc_get_order($order_id);
        $user_email = $order->get_billing_email();
        $invoice = new WIP_View_Invoice();
        $message = $invoice->set_order_id($order_id)
            ->set_type('invoice')
            ->set_is_email(true)
            ->get_template_html();

        $send_email = new WIP_Send_Email();
        $recipients = $this->options->get_option('recipients-email');
        $recipients = $recipients ? explode(PHP_EOL, $recipients) : null;

        if ($this->options->get_option('send-vendor')) {
            $vendors = $this->get_vendors($order_id);
            if (sizeof($vendors)) {
                foreach ($vendors as $vendor) {
                    $user_data = get_userdata($vendor);
                    $email = $user_data->user_email;
                    if ($email) {
                        $recipients[] = $email;
                    }
                }
            }
        }

        if (is_array($recipients) && count($recipients)) {
            foreach ($recipients as $recipient) {
                $send_email->send(trim($recipient), __('Invoice', 'wip'), $message);
            }
        }
        $send_email->send($user_email, __('Invoice', 'wip'), $message);
    }

    public function send_sms($order_id) {
        if (!$this->receiving_invoice($order_id)) {
            return null;
        }

        $order = wc_get_order($order_id);
        $user_phone = $order->get_billing_phone();

        $send_sms = new WIP_Send_SMS($order_id);
        $recipients = $this->options->get_option('recipients-phone');
        $recipients = $recipients ? explode(PHP_EOL, $recipients) : null;

        if ($this->options->get_option('send-vendor-sms')) {
            $vendors = $this->get_vendors($order_id);
            if (sizeof($vendors)) {
                foreach ($vendors as $vendor) {
                    $phone = get_user_meta($vendor, 'billing_phone', true);
                    if ($phone) {
                        $recipients[] = $phone;
                    }
                }
            }
        }

        if (is_array($recipients) && count($recipients)) {
            foreach ($recipients as $recipient) {
                $send_sms->send(trim($recipient));
            }
        }
        if ($user_phone) {
            $send_sms->send($user_phone);
        }
    }

    private function get_vendors($order_id) {
        $order = wc_get_order($order_id);

        $vendors = [];

        foreach ($order->get_items() as $id => $item) {
            $product = $item->get_product();
            $product_id = $product ? $product->get_id() : 0;
            $vendors[] = get_post_field('post_author', $product_id);
        }

        return array_unique($vendors);
    }
}