<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Order_MTB {

    public function __construct() {
        add_action('add_meta_boxes', [$this, 'add']);
        add_action('save_post', [$this, 'save']);
    }

    public function add() {
        add_meta_box(
            'wip-order-mtb',
            __('Invoicing', 'wip'),
            [$this, 'display'],
            'shop_order',
            'side',
            'low'
        );
    }

    public function display($post) {
        $order_id = $post->ID;

        $invoice_url = esc_url(
            add_query_arg(
                [
                    'action' => 'wip-print',
                    'type' => 'invoice',
                    'order-id' => WIP_Helper::generate_order_id($order_id, 'invoice'),
                    'wip-nonce' => wp_create_nonce('wip_nonce'),
                ],
                home_url()
            )
        );

        $packing_url = esc_url(
            add_query_arg(
                [
                    'action' => 'wip-print',
                    'type' => 'packing-slip',
                    'order-id' => WIP_Helper::generate_order_id($order_id, 'packing-slip'),
                    'wip-nonce' => wp_create_nonce('wip_nonce'),
                ],
                home_url()
            )
        );

        $label_url = esc_url(
            add_query_arg(
                [
                    'action' => 'wip-print',
                    'type' => 'post-label',
                    'order-id' => WIP_Helper::generate_order_id($order_id, 'post-label'),
                    'wip-nonce' => wp_create_nonce('wip_nonce'),
                ],
                home_url()
            )
        );

        $order_label_url = esc_url(
            add_query_arg(
                [
                    'action' => 'wip-print',
                    'type' => 'order-label',
                    'order-id' => WIP_Helper::generate_order_id($order_id, 'order-label'),
                    'wip-nonce' => wp_create_nonce('wip_nonce'),
                ],
                home_url()
            )
        );

        $mini_shop_label_url = esc_url(
            add_query_arg(
                [
                    'action' => 'wip-print',
                    'type' => 'shop-mini-label',
                    'order-id' => WIP_Helper::generate_order_id($order_id, 'shop-mini-label'),
                    'wip-nonce' => wp_create_nonce('wip_nonce'),
                ],
                home_url()
            )
        );

        $mini_customer_label_url = esc_url(
            add_query_arg(
                [
                    'action' => 'wip-print',
                    'type' => 'customer-mini-label',
                    'order-id' => WIP_Helper::generate_order_id($order_id, 'customer-mini-label'),
                    'wip-nonce' => wp_create_nonce('wip_nonce'),
                ],
                home_url()
            )
        );

        $invoice_note = get_post_meta($post->ID, '_wip_invoice_note', true);
        $packing_slip_note = get_post_meta($post->ID, '_wip_packing_slip_note', true);
        $transmission_date = get_post_meta($post->ID, '_wip_transmission_date', true);
        $disable_vendor = get_post_meta($post->ID, '_wip_disable_vendor', true);
        ?>
        <p>
            <a href="<?php echo $invoice_url; ?>" class="wip-button button" target="_blank"><?php _e('Invoice page', 'wip'); ?></a>
        </p>
        <p>
            <a href="<?php echo $packing_url; ?>" class="wip-button button" target="_blank"><?php _e('Packing slip page', 'wip'); ?></a>
        </p>
        <p>
            <a href="<?php echo $label_url; ?>" class="wip-button button" target="_blank"><?php _e('Post label page', 'wip'); ?></a>
        </p>
        <p>
            <a href="<?php echo $order_label_url; ?>" class="wip-button button" target="_blank"><?php _e('Order label page', 'wip'); ?></a>
        </p>
        <p>
            <a href="<?php echo $mini_shop_label_url; ?>" class="wip-button button" target="_blank"><?php _e('Shop mini label page', 'wip'); ?></a>
        </p>
        <p>
            <a href="<?php echo $mini_customer_label_url; ?>" class="wip-button button" target="_blank"><?php _e('Customer mini label page', 'wip'); ?></a>
        </p>
        <p>
            <button href="#" id="wip-send-invoice" class="wip-button button" data-id="<?php echo $post->ID; ?>"><?php _e('Send invoice to user', 'wip'); ?></button>
        </p>
        <p>
            <button href="#" id="wip-send-invoice-sms" class="wip-button button" data-id="<?php echo $post->ID; ?>"><?php _e('Send invoice sms to user', 'wip'); ?></button>
        </p>
        <p>
            <input type="text" class="wip-transmission-date" name="transmission-date" value="<?php echo esc_attr($transmission_date); ?>" placeholder="<?php _e('Transmission date', 'wip'); ?>">
        </p>
        <p>
            <textarea class="wip-invoice-note" name="invoice-note" rows="5" placeholder="<?php _e('Invoice note...', 'wip'); ?>"><?php echo esc_textarea($invoice_note); ?></textarea>
        </p>
        <p>
            <textarea class="wip-packing-slip-note" name="packing-slip-note" rows="5" placeholder="<?php _e('Packing slip note...', 'wip'); ?>"><?php echo esc_textarea($packing_slip_note); ?></textarea>
        </p>
        <p>
            <label>
                <input type="checkbox" name="disable-vendor" value="1" <?php checked($disable_vendor, 1); ?>>
                <?php _e('Disable for vendor', 'wip'); ?>
            </label>
        </p>
        <?php
        wp_nonce_field('security', 'wip_mtb_nonce');
    }

    public function save($post_id) {
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return;
        }

        if (!isset($_POST['wip_mtb_nonce']) || !wp_verify_nonce($_POST['wip_mtb_nonce'], 'security')) {
            return;
        }

        if (!current_user_can('edit_post')) {
            return;
        }

        if (!isset($_POST['transmission-date']) || empty($_POST['transmission-date'])) {
            delete_post_meta($post_id, '_wip_transmission_date');
        } else {
            update_post_meta($post_id, '_wip_transmission_date', sanitize_text_field($_POST['transmission-date']));
        }

        if (!isset($_POST['invoice-note']) || empty($_POST['invoice-note'])) {
            delete_post_meta($post_id, '_wip_invoice_note');
        } else {
            update_post_meta($post_id, '_wip_invoice_note', sanitize_textarea_field($_POST['invoice-note']));
        }

        if (!isset($_POST['packing-slip-note']) || empty($_POST['packing-slip-note'])) {
            delete_post_meta($post_id, '_wip_packing_slip_note');
        } else {
            update_post_meta($post_id, '_wip_packing_slip_note', sanitize_textarea_field($_POST['packing-slip-note']));
        }

        if (!isset($_POST['disable-vendor'])) {
            delete_post_meta($post_id, '_wip_disable_vendor');
        } else {
            update_post_meta($post_id, '_wip_disable_vendor', 1);
        }
    }
}