<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Orders_Table {

    private $options;
    private $labels;
    private $components;
    private $state;
    private $status;
    private $start_date;
    private $end_date;
    private $items_quantity = 0;
    private $total_amount = 0;
    private $total_provider_price = 0;

    public function __construct($state, $status, $start_date, $end_date) {
        $this->options = new WIP_Options_Manager();
        $this->labels = new WIP_Labels_Manager();
        $this->components = $this->options->get_option('components');
        $this->state = $state;
        $this->status = $status;
        $this->start_date = $start_date;
        $this->end_date = $end_date;
    }

    private function is_show($component) {
        return isset($this->components[$component]['orders']);
    }

    private function get_orders() {
        $args = array(
            'limit' => -1,
            'orderby' => 'date',
            'order' => 'DESC',
            'return' => 'ids',
        );

        if ($this->state && $this->state != 'all') {
            $args['billing_state'] = $this->state;
        }
        if ($this->status && $this->status != 'all') {
            $args['status'] = $this->status;
        }
        if (get_bloginfo('language') == 'fa-IR' && $this->start_date && $this->end_date) {
            list($date_start_y, $date_start_m, $date_start_d) = explode('-', $this->start_date);
            list($date_end_y, $date_end_m, $date_end_d) = explode('-', $this->end_date);

            $date_start_g = WIP_Jalali_Date::jalali_to_gregorian($date_start_y, $date_start_m, $date_start_d);
            $date_start_g = implode('-', $date_start_g);
            $date_end_g = WIP_Jalali_Date::jalali_to_gregorian($date_end_y, $date_end_m, $date_end_d);
            $date_end_g = implode('-', $date_end_g);

            $date_start_g = strtotime($date_start_g);
            $date_end_g = strtotime($date_end_g);

            $args['date_created'] = $date_start_g . '...' . $date_end_g;
        }

        $query = new WC_Order_Query($args);

        return $query->get_orders();
    }

    public function get_header($wc_countries) {
        $html = '<div class="header clearfix">';
        $html .= '<span class="title">' . esc_html($this->labels->get_label('orders')) . '</span>';
        $html .= '<span class="date">' . WIP_Helper::date_format(time()) . '</span>';
        if ($this->status && $this->status != 'all') {
            $html .= '<span class="status">' . wc_get_order_status_name($this->status) . '</span>';
        }
        if ($this->state && $this->state != 'all') {
            foreach ($wc_countries as $country) {
                $state = WIP_Helper::get_state($country, $this->state);
                if (!$state) {
                    continue;
                }
                $html .= '<span class="state">' . $state . '</span>';
            }
        }
        if ($this->start_date) {
            $html .= '<span class="start-date">' . $this->start_date . '</span>';
        }
        if ($this->end_date) {
            $html .= '<span class="end-date">' . $this->end_date . '</span>';
        }
        $html .= '</div>';

        return $html;
    }

    public function render_html() {
        $orders = $this->get_orders();
        if (!is_array($orders) || !count($orders)) {
            return null;
        }
        $i = 0;

        $table = '<table class="orders-table table-responsive table-bordered">';
        $table .= '<thead>';
        $table .= '<tr>';
        if ($this->is_show('order-row')) {
            $table .= '<th class="row">' . esc_html($this->labels->get_label('row')) . '</th>';
        }
        if ($this->is_show('order-id') || $this->is_show('order-status') || $this->is_show('order-date') || $this->is_show('order-meta')) {
            $table .= '<th class="order">' . esc_html($this->labels->get_label('order')) . '</th>';
        }
        if ($this->is_show('order-full-name') || $this->is_show('order-phone') || $this->is_show('order-email') || $this->is_show('order-national-id') || $this->is_show('order-user-meta')) {
            $table .= '<th class="customer">' . esc_html($this->labels->get_label('customer')) . '</th>';
        }
        if ($this->is_show('order-addr') || $this->is_show('order-postcode') || $this->is_show('order-shipping-method')) {
            $table .= '<th class="address">' . esc_html(str_replace(':', '', $this->labels->get_label('address'))) . '</th>';
        }
        if ($this->is_show('order-payment-method') || $this->is_show('order-transaction-id')) {
            $table .= '<th class="payment">' . esc_html($this->labels->get_label('payment')) . '</th>';
        }
        if ($this->is_show('order-transmission-date')) {
            $table .= '<th class="transmission-date">' . esc_html(str_replace(':', '', $this->labels->get_label('transmission-date'))) . '</th>';
        }
        if ($this->is_show('order-customer-note') || $this->is_show('order-note')) {
            $table .= '<th class="note">' . esc_html($this->labels->get_label('note')) . '</th>';
        }
        if ($this->is_show('order-products')) {
            $table .= '<th class="products">' . esc_html($this->labels->get_label('products')) . '</th>';
        }
        if ($this->is_show('order-price')) {
            $table .= '<th class="price">' . esc_html($this->labels->get_label('price')) . '</th>';
        }
        if ($this->is_show('order-provider-price')) {
            $table .= '<th class="provider-price">' . esc_html($this->labels->get_label('provider-price')) . '</th>';
        }
        $table .= '</tr>';
        $table .= '</thead>';
        $table .= '<tbody>';
        foreach ($orders as $order_id) {
            $order = wc_get_order($order_id);
            if (is_a($order, 'WC_Order_Refund')) {
                $order = wc_get_order($order->get_parent_id());
            }
            $this->items_quantity += $order->get_item_count();

            $order_data = new WIP_Order_Data($order_id, 'order');
            $customer_info = new WIP_Customer_Info($order_id, 'order');
            $shop_info = new WIP_Shop_Info($order_id, 'order');

            $table .= '<tr>';
            if ($this->is_show('order-row')) {
                $table .= '<td class="row">' . ($i + 1) . '</td>';
            }
            if ($this->is_show('order-id') || $this->is_show('order-status') || $this->is_show('order-date')) {
                $table .= '<td class="order">';
                if ($this->is_show('order-id')) {
                    $table .= '<div><a href="' . get_edit_post_link($order_id) . '" target="_blank">' . $order_data->get_order_id() . '</a></div>';
                }
                if ($this->is_show('order-status')) {
                    $table .= '<div>' . wc_get_order_status_name($order->get_status()) . '</div>';
                }
                if ($this->is_show('order-date')) {
                    $table .= '<div>' . $customer_info->get_order_date() . '</div>';
                }
                $table .= '</td>';
            }
            if ($this->is_show('order-full-name') || $this->is_show('order-phone') || $this->is_show('order-email') || $this->is_show('order-national-id')) {
                $table .= '<td class="customer">';
                if ($this->is_show('order-full-name')) {
                    $table .= '<div>' . $customer_info->get_full_name() . '</div>';
                }
                if ($this->is_show('order-national-id')) {
                    $table .= '<div>' . $customer_info->get_national_id() . '</div>';
                }
                if ($this->is_show('order-email')) {
                    $table .= '<div>' . $customer_info->get_email() . '</div>';
                }
                if ($this->is_show('order-phone')) {
                    $table .= '<div>' . $customer_info->get_phone() . '</div>';
                }
                $table .= '</td>';
            }
            if ($this->is_show('order-addr') || $this->is_show('order-postcode') || $this->is_show('order-shipping-method')) {
                $table .= '<td class="address">';
                if ($this->is_show('order-addr')) {
                    $table .= '<div>' . $customer_info->get_address() . '</div>';
                }
                if ($this->is_show('order-postcode')) {
                    $table .= '<div>' . $customer_info->get_postcode() . '</div>';
                }
                if ($this->is_show('order-shipping-method')) {
                    $table .= '<div>' . $customer_info->get_shipping_method() . '</div>';
                }
                $table .= '</td>';
            }
            if ($this->is_show('order-payment-method') || $this->is_show('order-transaction-id')) {
                $table .= '<td class="payment">';
                if ($this->is_show('order-payment-method')) {
                    $table .= '<div>' . $customer_info->get_payment_method() . '</div>';
                }
                if ($this->is_show('order-transaction-id')) {
                    $table .= '<div>' . $customer_info->get_transaction_id() . '</div>';
                }
                $table .= '</td>';
            }
            if ($this->is_show('order-transmission-date')) {
                $table .= '<td class="transmission-date">';
                $table .= '<div>' . $shop_info->get_transmission_date() . '</div>';
                $table .= '</td>';
            }
            if ($this->is_show('order-customer-note') || $this->is_show('order-note')) {
                $table .= '<td class="note">';
                if ($this->is_show('order-customer-note')) {
                    $table .= '<div>' . $order_data->get_order_note() . '</div>';
                }
                if ($this->is_show('order-note')) {
                    $table .= '<div>' . $order_data->get_customer_note() . '</div>';
                }
                $table .= '</td>';
            }
            if ($this->is_show('order-products')) {
                $table .= '<td class="products">' . $this->get_products($order) . '</td>';
            }
            if ($this->is_show('order-price')) {
                $table .= '<td class="price">' . $this->get_price($order) . '</td>';
            }
            if ($this->is_show('order-provider-price')) {
                $table .= '<td class="provider">' . $this->get_provider_price($order) . '</td>';
            }
            $table .= '</tr>';

            $i++;
        }
        $table .= '</tbody>';
        $table .= '</table>';
        if ($this->is_show('order-total')) {
            $table .= $this->get_totals();
        }

        return $table;
    }

    private function get_customer($order) {
        return '<div>' . $order->get_billing_first_name() . ' ' . $order->get_billing_last_name() . '</div><div>' . $order->get_billing_phone() . '</div>';
    }

    private function get_state($order) {
        return WIP_Helper::get_state($order->get_billing_country(), $order->get_billing_state()) . '/' . $order->get_billing_city();
    }

    private function get_products($order) {
        $i = 0;
        $html = '';
        $total_qty = 0;
        foreach ($order->get_items() as $id => $item) {
            $data = $item->get_data();
            $product = $item->get_product();
            $product_id = $data['product_id'];
            $name = $data['name'];
            $quantity = $item->get_quantity();

            $html .= '<div>';
            $html .= '<span>' . ($i + 1) . '- ' . $name . '</span>';
            $html .= '<span> | ' . $this->labels->get_label('quantity') . ':' . $quantity . '</span>';
            $html .= '<span> | ' . $this->labels->get_label('id') . ':' . $this->get_id($product, $product_id) . '</span>';
            $html .= '</div>';

            $i++;
            $total_qty += $item->get_quantity();
        }
        $html .= '<div class="total">' . $this->labels->get_label('total-items') . $total_qty . '</div>';

        return $html;
    }

    private function get_id($product, $product_id) {
        if (!$product) {
            return null;
        }
        $sku = $product->get_sku();
        if ($this->options->get_option('id-type') == 'sku' && $sku) {
            return $sku;
        }

        return $product_id;
    }

    private function get_order_date($order) {
        return '<div>' . WIP_Helper::date_format(strtotime($order->get_date_created())) . '</div><div>' . $order->get_payment_method_title() . '</div>';
    }

    private function get_price($order) {
        $html = '';
        $total = 0;
        foreach ($order->get_items() as $id => $item) {
            $this->total_amount += $item->get_total();

            $price = $item->get_total() / $item->get_quantity();
            $html .= '<div>' . wc_price($price) . '</div>';

            $total += $item->get_total();
        }
        $html .= '<di class="total">' . $this->labels->get_label('total-amount') . wc_price($total) . '</div>';

        return $html;
    }

    private function get_provider_price($order) {
        $html = '';
        foreach ($order->get_items() as $id => $item) {
            $product = $item->get_product();
            if (!$product) {
                continue;
            }

            $data = $item->get_data();
            $product_id = $data['product_id'];
            $variation_id = $data['variation_id'];
            $quantity = $item->get_quantity();
            if ($variation_id) {
                $product_id = $variation_id;
            }

            $price = get_post_meta($product_id, '_wsm_provider_price', true);

            $this->total_provider_price += (intval($price) * $quantity);

            $price = $price ? wc_price($price) : '__';
            $html .= '<div>' . $price . '</div>';
        }

        return $html;
    }

    private function get_totals() {
        $html = '<div class="totals">';
        $html .= '<div><span>' . $this->labels->get_label('quantity') . '</span><span>' . $this->items_quantity . '</span></div>';
        $html .= ' | <div><span>' . $this->labels->get_label('price') . '</span><span>' . wc_price($this->total_amount) . '</span></div>';
        $html .= ' | <div><span>' . $this->labels->get_label('provider-price') . '</span><span>' . wc_price($this->total_provider_price) . '</span></div>';
        $html .= '</div>';

        return $html;
    }
}