<?php
defined( 'ABSPATH' ) || exit( __( 'No Access!', 'wip' ) );

class WIP_Our_Products {

	const JSON_URL = 'http://sreza-salehi.ir/products/products.json';
	const TRANSIENT_SLUG = 'srs_products';
	const EXPIRATION = 6 * 3600;
	private $data;
	private $text_domain;

	public function __construct( $text_domain ) {
		$this->text_domain = $text_domain;
		$this->prepare_data();
	}

	private function prepare_data() {
		$transient = get_transient( self::TRANSIENT_SLUG );
		if ( ! $transient && $this->get_http_response_code( self::JSON_URL ) == "200" ) {
			$json = file_get_contents( self::JSON_URL );
			set_transient( self::TRANSIENT_SLUG, $json, self::EXPIRATION );
			$this->data = json_decode( $json );
		} else {
			$this->data = json_decode( $transient );
		}
	}

	private function get_http_response_code( $url ) {
		$headers = get_headers( $url );

		return substr( $headers[0], 9, 3 );
	}

	public function render_html() {
		if ( ! is_array( $this->data ) || ! count( $this->data ) ) {
			return null;
		}

		$lang = get_locale() == 'fa_IR' ? 'fa' : 'en';
		$html = '';
		foreach ( $this->data as $product ) {
			$html .= '<div class="srs-item">';
			$html .= '<div class="uk-card uk-card-default">';
			$html .= '<div class="uk-card-header">';
			$html .= '<img class="srs-image" src="' . $product->image . '" height="80" width="80" alt="icon">';
			$html .= isset( $product->discount ) ? '<span class="srs-discount uk-badge">' . $product->discount . '%</span>' : null;
			$html .= '</div>';
			$html .= '<div class="uk-card-body">';
			$html .= '<p class="srs-title">' . $product->title->$lang . '</p>';
			$html .= '<span class="srs-price">' . number_format( $product->price ) . '&nbsp;' . __( 'Toman', $this->text_domain ) . '</span>';
			$html .= '</div>';
			$html .= '<div class="uk-card-footer">';
			$html .= '<a data-clear="srs-url" href="' . $product->url . '" class="uk-button uk-button-text" target="_blank">' . __( 'View product', $this->text_domain ) . '</a>';
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
		}

		return $html;
	}
}