<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Pre_Products_Table extends WIP_Products_Table {

    use WIP_Product_Data;

    private $items;

    public function __construct($order_id, $type) {
        parent::__construct($order_id, $type);
        $this->items = WC()->cart->get_cart();
    }

    public function render_html() {
        if (!isset($this->components['products-table']['pre-invoice'])) {
            return null;
        }
        if (!is_array($this->items)) {
            return null;
        }

        $id_label = $this->labels->get_label('id');
        $image_label = $this->labels->get_label('image');
        $product_label = $this->labels->get_label('product');
        $weight_label = $this->labels->get_label('weight');
        $dimension_label = $this->labels->get_label('dimension');
        $cabinet_label = $this->labels->get_label('cabinet-code');
        $price_label = $this->labels->get_label('price');
        $discount_label = $this->labels->get_label('discount-amount');
        $quantity_label = $this->labels->get_label('quantity');
        $total_label = $this->labels->get_label('total-amount');
        $note_label = $this->labels->get_label('purchase-note');

        $product_meta = $this->options->get_option('product-meta');
        $col_span = 0;
        $total_discount = 0;
        $total_quantity = 0;
        $total_amount = 0;

        $table = '<table class="products-table table-responsive table-bordered">';
        $table .= '<thead>';
        $table .= '<tr>';
        if ($this->is_show('products-row')) {
            $table .= '<th class="row">#</th>';
            $col_span++;
        }
        if ($this->is_show('products-id')) {
            $table .= '<th class="id">' . esc_html($id_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-image')) {
            $table .= '<th class="image">' . esc_html($image_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-product')) {
            $table .= '<th class="product">' . esc_html($product_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-weight')) {
            $table .= '<th class="weight">' . esc_html($weight_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-dimension')) {
            $table .= '<th class="dimension">' . esc_html($dimension_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-cabinet-code')) {
            $table .= '<th class="cabinet-code">' . esc_html($cabinet_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-price')) {
            $table .= '<th class="price">' . esc_html($price_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-extra-column')) {
            if ($product_meta && is_array($product_meta)) {
                foreach ($product_meta as $value) {
                    list($label, $key) = explode('@', $value);
                    $table .= '<th class="meta">' . esc_html($label) . '</th>';
                    $col_span++;
                }
            }
        }
        if ($this->is_show('products-discount')) {
            $table .= '<th class="discount-amount">' . esc_html($discount_label) . '</th>';
        }
        if ($this->is_show('products-quantity')) {
            $table .= '<th class="quantity">' . esc_html($quantity_label) . '</th>';
        }
        if ($this->is_show('products-total')) {
            $table .= '<th class="total-amount">' . esc_html($total_label) . '</th>';
        }
        if ($this->is_show('products-purchase-note')) {
            $table .= '<th class="note">' . esc_html($note_label) . '</th>';
        }
        $table .= '</tr>';
        $table .= '</thead>';
        $table .= '<tbody>';

        $i = 0;
        foreach ($this->items as $item => $values) {
            $product_id = $values['data']->get_id();
            $product = wc_get_product($values['data']->get_id());
            $name = $product->get_name();
            $quantity = $values['quantity'];
            $price = $this->get_price($product_id);
            $item_data = $this->options->get_option('show-pre-invoice-variation') ? wc_get_formatted_cart_item_data($values) : '';

            $table .= '<tr class="' . ($i % 2 == 0 ? 'odd' : 'even') . '">';
            if ($this->is_show('products-row')) {
                $table .= '<td class="row">' . ($i + 1) . '</td>';
            }
            if ($this->is_show('products-id')) {
                $table .= '<td class="id"><span class="td-title">' . esc_html($id_label) . '</span>' . $this->get_id($product_id) . '</td>';
            }
            if ($this->is_show('products-image')) {
                $table .= '<td class="image">' . $this->get_image($product_id) . '</td>';
            }
            if ($this->is_show('products-product')) {
                $table .= '<td class="product"><span class="td-title">' . esc_html($product_label) . '</span><a href="' . get_permalink($product_id) . '" target="_blank">' . $this->get_title($name, $product, $item) . '</a>' . $item_data . '</td>';
            }
            if ($this->is_show('products-weight')) {
                $table .= '<td class="weight"><span class="td-title">' . esc_html($weight_label) . '</span><bdi dir="ltr">' . $this->get_weight($product, $quantity) . '</bdi></td>';
            }
            if ($this->is_show('products-dimension')) {
                $table .= '<td class="dimension"><span class="td-title">' . esc_html($dimension_label) . '</span><bdi dir="ltr">' . $this->get_dimensions($product) . '</bdi></td>';
            }
            if ($this->is_show('products-cabinet-code')) {
                $table .= '<td class="cabinet-code"><span class="td-title">' . esc_html($cabinet_label) . '</span>' . $this->get_cabinet_code($product_id) . '</td>';
            }
            if ($this->is_show('products-price')) {
                $table .= '<td class="price"><span class="td-title">' . esc_html($price_label) . '</span>' . $this->get_price_html($product) . '</td>';
            }
            if ($this->is_show('products-extra-column')) {
                if ($product_meta && is_array($product_meta)) {
                    foreach ($product_meta as $value) {
                        list($label, $key) = explode('@', $value);
                        $meta_value = get_post_meta($product_id, $key, true);
                        $table .= '<td class="meta"><span class="td-title">' . esc_html(esc_attr($label)) . '</span>' . esc_html($meta_value) . '</td>';
                    }
                }
            }
            if ($this->is_show('products-discount')) {
                $discount = $this->get_discount($product, $quantity);
                $total_discount += $discount;
                $table .= '<td class="discount-amount"><span class="td-title">' . esc_html($discount_label) . '</span>' . wc_price($discount) . '</td>';
            }
            if ($this->is_show('products-quantity')) {
                $total_quantity += $quantity;
                $table .= '<td class="quantity"><span class="td-title">' . esc_html($quantity_label) . '</span>' . $quantity . '</td>';
            }
            if ($this->is_show('products-total')) {
                $total = $price * $quantity;
                $total_amount += $total;
                $table .= '<td class="total-amount"><span class="td-title">' . esc_html($total_label) . '</span>' . wc_price($total) . '</td>';
            }
            if ($this->is_show('products-purchase-note')) {
                $table .= '<td class="note"><span class="td-title">' . esc_html($note_label) . '</span>' . $this->get_purchase_note($product) . '</td>';
            }
            $table .= '</tr>';

            $i++;
        }

        $table .= '</tbody>';
        $table .= $this->get_footer($col_span, $total_discount, $total_quantity, $total_amount);
        $table .= '</table>';

        $table .= $this->get_total_weight();

        return $table;
    }

    private function get_price($product_id) {
        $product = wc_get_product($product_id);

        return intval($product->get_price());

        return intval(get_post_meta($product_id, '_price', true));
    }

    private function get_price_html($product) {
        $product_id = $product->get_id();
        if (!$this->options->get_option('regular-price')) {
            return wc_price($this->get_price($product_id));
        }

        return $product->is_on_sale() ? '<del>' . wc_price($product->get_regular_price()) . '</del><ins>' . wc_price($product->get_sale_price()) . '</ins>' : wc_price($product->get_regular_price());

    }

    private function get_discount($product, $quantity) {
        if (!$product->is_on_sale()) {
            return 0;
        }
        $regular_price = (float)$product->get_regular_price();
        $sale_price = (float)$product->get_price();

        return ($regular_price - $sale_price) * $quantity;
    }

    private function get_footer($col_span, $discount, $quantity, $total) {
        if (!isset($this->components['products-footer'][$this->type])) {
            return null;
        }

        $html = '<tfoot>';
        $html .= '<tr>';
        if ($col_span) {
            $html .= '<th class="total" colspan="' . $col_span . '">' . $this->labels->get_label('total') . '</th>';
        }
        if ($this->is_show('products-discount')) {
            $html .= '<td class="discount-amount">' . wc_price($discount) . '</td>';
        }
        if ($this->is_show('products-quantity')) {
            $html .= '<td class="quantity">' . $quantity . '</td>';
        }
        if ($this->is_show('products-total')) {
            $cs = isset($this->components['products-purchase-note'][$this->type]) ? 'colspan="2"' : null;
            $html .= '<td class="total-amount" ' . $cs . '>' . wc_price($total) . '</td>';
        }
        $html .= '</tr>';
        $html .= '</tfoot>';

        return $html;
    }

    private function get_total_weight() {
        $html = '';
        if ($this->is_show('total-weight')) {
            $html = '<div class="weight-wrapper">';
            $html .= '<div class="total-weight">';
            $html .= '<span class="title">' . $this->labels->get_label('total-weight') . '</span>';
            $html .= '<span class="content"><bdi dir="ltr">' . wc_format_weight(WC()->cart->get_cart_contents_weight()) . '</bdi></span>';
            $html .= '</div>';
            $html .= '</div>';
        }

        return $html;
    }
}