<?php
defined( 'ABSPATH' ) || exit( __( 'No Access!', 'wip' ) );

class WIP_Shop_Info extends WIP_Order_Data {

	private $is_dokan_dashboard = false;

	public function __construct( $order_id, $type ) {
		parent::__construct( $order_id, $type );
		$this->is_dokan_dashboard = isset( $_GET['is-vendor'] );
	}

	private function get_logo() {
		return $this->options->get_option( 'shop-logo' );
	}

	private function get_title() {
		return $this->options->get_option( 'shop-title' );
	}

	private function get_economical_num() {
		return $this->options->get_option( 'shop-economical-num' );
	}

	private function get_reg_num() {
		return $this->options->get_option( 'shop-reg-num' );
	}

	private function get_url() {
		return $this->options->get_option( 'shop-url' );
	}

	private function get_postcode() {
		$vendor_address = $this->options->get_option( 'vendor-address' );
		if ( $vendor_address && $this->is_dokan_dashboard ) {
			return $this->get_vendor_info()['zip'];
		}

		return $this->options->get_option( 'shop-postcode' );
	}

	private function get_email() {
		return $this->options->get_option( 'shop-email' );
	}

	private function get_phone() {
		return $this->options->get_option( 'shop-phone' );
	}

	private function get_address() {
		$vendor_address = $this->options->get_option( 'vendor-address' );
		if ( $vendor_address && $this->is_dokan_dashboard ) {
			return $this->get_vendor_info()['address'];
		}

		return $this->options->get_option( 'shop-address' );
	}

	private function get_vendor_info() {
		$vendor_id = get_current_user_id();
		$profile   = get_user_meta( $vendor_id, 'dokan_profile_settings', true );
		if ( ! is_array( $profile ) ) {
			return null;
		}
		$address    = $profile['address'] ?? [];
		$country    = $address['country'] ?? '';
		$state      = $address['state'] ?? '';
		$state_name = WIP_Helper::get_state( $country, $state );
		if ( $state_name ) {
			$state = $state_name;
		}
		$city     = $address['city'] ?? '';
		$street_1 = $address['street_1'] ?? '';
		$street_2 = $address['street_2'] ?? '';
		$zip      = $address['zip'] ?? '';

		return [
			'address' => ( $state ? $state . ' - ' : '' ) . ( $city ? $city . ' - ' : '' ) . ( $street_1 ? $street_1 . ' - ' : '' ) . $street_2,
			'zip'     => $zip,
		];
	}

	public function get_transmission_date() {
		return get_post_meta( $this->order_id, '_wip_transmission_date', true );
	}

	public function get_print_date_html() {
		if ( $this->is_show( 'print-date' ) ) {
			return $this->get_html( 'print-date', WIP_Helper::date_format( time() ) );
		}

		return null;
	}

	public function get_order_id_html() {
		if ( $this->is_show( 'order-id' ) ) {
			return $this->get_html( 'order-id', $this->get_order_id() );
		}

		return null;
	}

	public function get_order_status_html() {
		if ( $this->is_show( 'order-status' ) ) {
			return $this->get_html( 'order-status', wc_get_order_status_name( $this->order->get_status() ) );
		}

		return null;
	}

	public function get_logo_html() {
		$logo = $this->get_logo();
		if ( $logo && $this->is_show( 'shop-logo' ) ) {
			return '<div class="shop-logo"><img src="' . wp_get_attachment_url( $logo ) . '"></div>';
		}

		return null;
	}

	public function get_title_html() {
		$title = $this->get_title();
		if ( $title && $this->is_show( 'shop-title' ) ) {
			return $this->get_html( 'title', $title );
		}

		return null;
	}

	public function get_barcode_html() {
		$barcode_type = $this->options->get_option( 'barcode-type' );
		if ( $this->is_show( 'barcode' ) ) {
			if ( $barcode_type == 'qrcode' ) {
				return '<div class="barcode"><img src="https://chart.googleapis.com/chart?chs=150x150&cht=qr&chl=' . $this->get_order_id() . 'choe=UTF-8"></div>';
			} else {
				$generator = new Picqer\Barcode\BarcodeGeneratorSVG();

				return '<div class="barcode">' . $generator->getBarcode( $this->get_order_id(), $generator::TYPE_CODE_128 ) . '</div>';
			}
		}

		return null;
	}

	public function get_economical_num_html() {
		$economical_num = $this->get_economical_num();
		if ( $economical_num && $this->is_show( 'shop-economical-num' ) ) {
			return $this->get_html( 'economical-num', $economical_num );
		}

		return null;
	}

	public function get_reg_num_html() {
		$reg_num = $this->get_reg_num();
		if ( $reg_num && $this->is_show( 'shop-reg-num' ) ) {
			return $this->get_html( 'reg-num', $reg_num );
		}

		return null;
	}

	public function get_url_html() {
		$url = $this->get_url();
		if ( $url && $this->is_show( 'shop-url' ) ) {
			return $this->get_html( 'url', $url );
		}

		return null;
	}

	public function get_postcode_html() {
		$postcode = $this->get_postcode();
		if ( $postcode && $this->is_show( 'shop-postcode' ) ) {
			return $this->get_html( 'postcode', $postcode );
		}

		return null;
	}

	public function get_email_html() {
		$email = $this->get_email();
		if ( $email && $this->is_show( 'shop-email' ) ) {
			return $this->get_html( 'email', $email );
		}

		return null;
	}

	public function get_phone_html() {
		$phone = $this->get_phone();
		if ( $phone && $this->is_show( 'shop-phone' ) ) {
			return $this->get_html( 'phone', $phone );
		}

		return null;
	}

	public function get_address_html() {
		$address = $this->get_address();
		if ( $address && $this->is_show( 'shop-address' ) ) {
			return $this->get_html( 'address', $address );
		}

		return null;
	}

	public function get_get_transmission_date_html() {
		$date = $this->get_transmission_date();
		if ( $date && $this->is_show( 'transmission-date' ) ) {
			return $this->get_html( 'transmission-date', $date );
		}

		return null;
	}
}